
/* Sugar colors */
@define-color black #000000;
@define-color toolbar_grey #282828;
@define-color button_grey /*#ff0000*/ #808080 ;
@define-color selection_grey #A6A6A6;
@define-color panel_grey #C0C0C0;
@define-color text_field_grey #E5E5E5;
@define-color row_even #E5E5E5;
@define-color row_odd #D5D5D5;
@define-color white #FFFFFF;
@define-color zoom_views_prelight #E8E8E8;
@define-color zoom_views_active #B3B3B3;

/* Default color scheme */
@define-color base_color #ffffff;
@define-color bg_color #ededed;
@define-color tooltip_bg_color #343434;
@define-color selected_bg_color #4a90d9;
@define-color text_color #2e3436;
@define-color fg_color #2e3436;
@define-color tooltip_fg_color #ffffff;
@define-color selected_fg_color #ffffff;

/* Colormap actually used by the theme, to be overridden in other css files */
@define-color theme_base_color @base_color;

@import url("gtk-widgets.css");

